@@ -662,3 +662,107 @@ quote_s_re () {
   sed -e 's/[\/&]/\\&/g' <<< "$1"
 }
 
+# Scans the file given as parameter1 for uncommentented lines starting with
+# either the old style JAVA_XTRAOPTS or the post RM-177 style JAVA_OPTS_MEM for
+# the JVM max heap size configuration option given as either -Xmx or
+# -XX:MaxHeapSize.
+#
+# Param1: The file to read the maximum heap size from
+# Return: The first found config option for the JVM's max heap size or "n/a"
+#         if either the file can't be read or the option can't be found
+# Example:
+#
+#   root@host:~$ max_heap=$(ox_get_max_heap /opt/open-xchange/etc/ox-scriptconf.sh)
+#   root@host:~$ echo ${max_heap}
+#   root@host:~$ 512M
+#
+ox_get_max_heap() {
+  local config_file="${1}"
+  test -z "${config_file}" && die "ox_get_max_heap: missing config file argument (arg 1)"
+  if [ -r "${config_file}" ]
+  then
+    local max_heap=$(awk '/^JAVA_XTRAOPTS|^JAVA_OPTS_MEM/ {
+      gsub("JAVA.[^\"]*","")
+      gsub("\"","")
+      num_opts = split($0, mem_opts, " ")
+      for (x=1; x <= num_opts; ++x) {
+        if (mem_opts[x] ~ /-Xmx/) {
+          gsub("-Xmx","", mem_opts[x])
+          print mem_opts[x]
+          exit
+        } else if (mem_opts[x] ~ /-XX:MaxHeapSize/) {
+          split(mem_opts[x], heap_size , "=")
+          print heap_size[2]
+          exit
+        }
+      }
+    }' "${config_file}")
+  fi
+  local max_heap=${max_heap:-"n/a"}
+  echo "${max_heap}"
+}
+
+# Scans the file given as parameter1 for uncommentented lines starting with
+# either the old style JAVA_XTRAOPTS or the post RM-177 style JAVA_OPTS_MEM for
+# the JVM max heap size configuration option given as either -Xmx or
+# -XX:MaxHeapSize and sets it to the new value given as parameter2
+#
+# Param1: The file to set the maximum heap size in
+# Param2: The new maximum heap size e.g. 768M or 2G
+# Return: 0 if the new value was set, 1 otherwise
+# Example:
+#
+#   root@host:~$ $(ox_set_max_heap /opt/open-xchange/etc/ox-scriptconf.sh 2G)
+#   && echo set new value
+#   set new value
+#   root@host:~$ 
+#
+ox_set_max_heap() {
+  local config_file="${1}"
+  local new_value="${2}"
+  test -z "${config_file}" && die "ox_set_max_heap: missing config file argument (arg 1)"
+  test -z "${new_value}" && die "ox_set_max_heap: missing new value argument (arg 2)"
+
+  # read
+  local opts_line=$(ox_read_property JAVA_XTRAOPTS "${config_file}")
+  if [[ -z "${opts_line}" ]]
+  then
+    opts_line=$(ox_read_property JAVA_OPTS_MEM "${config_file}")
+    local new_style=1
+  fi
+  [[ -z "${opts_line}" ]] && return 1
+
+  # unquote
+  local opts=($(sed -e 's/\"//g' <<< "${opts_line}"))
+
+  # modify
+  local num_opts=${#opts[@]}
+  for ((i=0; i < num_opts; i++))
+  do
+    if [[ "${opts[$i]}" =~ -XX:MaxHeapSize ]]
+    then
+      opts[$i]="-XX:MaxHeapSize=${new_value}"
+      local modified=1
+      break
+    elif [[ "${opts[${i}]}" =~ -Xmx ]]
+    then
+      opts[$i]="-Xmx${new_value}"
+      local modified=1
+      break
+    fi
+  done
+  
+  ((modified)) || return 1
+
+  # quote
+  new_opts_line=\"${opts[*]}\"
+  
+  # persist
+  if ((new_style))
+  then
+    ox_set_property JAVA_OPTS_MEM "${new_opts_line}" "${config_file}"
+  else
+    ox_set_property JAVA_XTRAOPTS "${new_opts_line}" "${config_file}"
+  fi
+  return $?
+}
